pub struct Contest {
    pub template: Template,
    pub problems: Vec<Problem>,
    pub problem_count: Option<u32>,
    pub vars: HashMap<String, String>,
}

Fields

template: Templateproblems: Vec<Problem>problem_count: Option<u32>vars: HashMap<String, String>

Implementations

Check whether the contest has the proper vars defined, and each problem has the proper problemvars and solutionvars defined

Compiles the contest given a template directory to query