pub struct Contest {
pub template: Template,
pub problems: Vec<Problem>,
pub problem_count: Option<u32>,
pub vars: HashMap<String, String>,
}Fields
template: Templateproblems: Vec<Problem>problem_count: Option<u32>vars: HashMap<String, String>Implementations
sourceimpl Contest
impl Contest
sourcepub fn check_template(&self) -> Option<Vec<MapmErr>>
pub fn check_template(&self) -> Option<Vec<MapmErr>>
Check whether the contest has the proper vars defined, and each problem has the proper problemvars and solutionvars defined
sourcepub fn compile<T: AsRef<Path>>(&self, template_dir: T) -> ContestCompileResults
pub fn compile<T: AsRef<Path>>(&self, template_dir: T) -> ContestCompileResults
Compiles the contest given a template directory to query